@@ -7,4 +7,7 @@ class LrLogger(Callback):
     def on_train_epoch_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
         for i, optimizer in enumerate(trainer.optimizers):
             for j, params in enumerate(optimizer.param_groups):
-                pl_module.log(f"opt{i}_lr{j}", params["lr"])
+                key = f"opt{i}_lr{j}"
+                value = params["lr"]
+                pl_module.logger.log_metrics({key: value}, step=trainer.global_step)
+                pl_module.log(key, value, logger=False, sync_dist=pl_module.distributed)
