@@ -1,7 +1,7 @@
 from .iou import iou_1d, iou_2d
 from .psnr import psnr_video, psnr_image
 from .ssim import ssim_video, ssim_image
-from .enum import Reduction
+from .fid import FID
 
 __all__ = [
     "iou_1d",
@@ -10,5 +10,5 @@ __all__ = [
     "psnr_image",
     "ssim_video",
     "ssim_image",
-    "Reduction",
+    "FID",
 ]
