@@ -2,7 +2,8 @@ from .enum import ResizeMethod, PaddingMethod, PaddingPosition
 from .pad import padding_video, padding_audio
 from .resize import resize_image, resize_video
 from .crop import crop_with_padding
-from tensorneko_util.preprocess import ffmpeg_available, frames2video
+from tensorneko_util.preprocess import frames2video
+from tensorneko_util.backend import VisualLib
 
 __all__ = [
     "ResizeMethod",
@@ -16,7 +17,7 @@ __all__ = [
     "frames2video"
 ]
 
-if ffmpeg_available:
+if VisualLib.ffmpeg_available():
     from tensorneko_util.preprocess import video2frames, ffmpeg_command, merge_video_audio, resample_video_fps, mp32wav
     __all__.extend(["video2frames", "ffmpeg_command", "merge_video_audio", "resample_video_fps", "mp32wav"])
 
