@@ -1,11 +1,13 @@
 from .log_graph import log_graph
 from tensorneko_util.visualization import Colors, ContinuousColors, tensorboard
 from . import watcher
+from . import image_browser
 from ..backend import VisualLib
 
 __all__ = [
     "log_graph",
     "watcher",
+    "image_browser",
     "tensorboard",
     "Colors",
     "ContinuousColors",
